@@ -1,8 +1,9 @@
 package File::ConfigDir;
 
-use warnings;
 use strict;
-use vars qw($VERSION @ISA @EXPORT @EXPORT_OK %EXPORT_TAGS);
+use warnings;
+use parent 'Exporter';
+use vars qw($VERSION @EXPORT_OK %EXPORT_TAGS);
 
 use Carp qw(croak);
 use Config;
@@ -16,11 +17,16 @@ use File::Spec     ();
 
 File::ConfigDir - Get directories of configuration files
 
+=begin html
+
+<a href="https://travis-ci.org/perl5-utils/File-ConfigDir"><img src="https://travis-ci.org/perl5-utils/File-ConfigDir.svg?branch=master" alt="Travis CI"/></a>
+<a href='https://coveralls.io/github/perl5-utils/File-ConfigDir?branch=master'><img src='https://coveralls.io/repos/github/perl5-utils/File-ConfigDir/badge.svg?branch=master' alt='Coverage Status'/></a>
+
+=end html
+
 =cut
 
-$VERSION   = '0.018';
-@ISA       = qw(Exporter);
-@EXPORT    = ();
+$VERSION   = '0.019';
 @EXPORT_OK = (
     qw(config_dirs system_cfg_dir desktop_cfg_dir),
     qw(xdg_config_dirs machine_cfg_dir),
@@ -33,16 +39,10 @@ $VERSION   = '0.018';
     ALL => [@EXPORT_OK],
 );
 
-my $haveFileHomeDir = 0;
-eval {
-    require File::HomeDir;
-    $haveFileHomeDir = 1;
-};
-
-eval "use List::MoreUtils qw/uniq/;";
-__PACKAGE__->can("uniq") or eval <<'EOP';
+eval "use List::MoreUtils qw/distinct/;";    ## no strict (BuiltinFunctions::ProhibitStringyEval)
+__PACKAGE__->can("distinct") or eval <<'EOP';
     # from PP part of List::MoreUtils
-sub uniq(&@) {
+sub distinct(&@) {
     my %h;
     map { $h{$_}++ == 0 ? $_ : () } @_;
 }
@@ -364,17 +364,20 @@ C<etc> directory below it.
 
 =cut
 
+my $haveLocalLib;
+
+BEGIN
+{
+    # uncoverable branch false
+    defined $haveLocalLib or $haveLocalLib = eval "use local::lib (); local::lib->can('active_paths');";
+    defined $haveLocalLib or $haveLocalLib = 0;
+}
+
 my $locallib_cfg_dir = sub {
     my @cfg_base = @_;
     my @dirs;
 
-    if (   $INC{'local/lib.pm'}
-        && $ENV{PERL_MM_OPT}
-        && $ENV{PERL_MM_OPT} =~ m/.*INSTALL_BASE=([^"']*)['"]?$/)
-    {
-        (my $cfgdir = $ENV{PERL_MM_OPT}) =~ s/.*INSTALL_BASE=([^"']*)['"]?$/$1/;
-        push(@dirs, File::Spec->catdir($cfgdir, "etc", @cfg_base));
-    }
+    $haveLocalLib and push(@dirs, map { File::Spec->catdir($_, "etc", @cfg_base) } local::lib->active_paths);
 
     @dirs;
 };
@@ -407,6 +410,15 @@ sub here_cfg_dir
     $here_cfg_dir->(@cfg_base);
 }
 
+my $haveFileHomeDir;
+
+BEGIN
+{
+    # uncoverable branch false
+    defined $haveFileHomeDir or $haveFileHomeDir = eval "use File::HomeDir; 1";
+    defined $haveFileHomeDir or $haveFileHomeDir = 0;
+}
+
 =head2 user_cfg_dir
 
 Returns the users home folder using L<File::HomeDir>. Without
@@ -418,7 +430,12 @@ my $user_cfg_dir = sub {
     my @cfg_base = @_;
     my @dirs;
 
-    $haveFileHomeDir and @dirs = (File::Spec->catdir(File::HomeDir->my_home(), map { "." . $_ } @cfg_base));
+    my $homedir;
+    $haveFileHomeDir and $homedir = File::HomeDir->my_home();
+    $homedir |= $ENV{HOME} if defined $ENV{HOME};
+    $homedir |= File::Spec->catpath($ENV{HOMEDRIVE}, $ENV{HOMEPATH}) if defined $ENV{HOMEDRIVE} and defined $ENV{HOMEPATH};
+
+    $homedir and @dirs = (File::Spec->catdir($homedir, map { "." . $_ } @cfg_base));
 
     @dirs;
 };
@@ -501,7 +518,7 @@ sub config_dirs
         push(@dirs, $extensible_bases[$idx]->(($pure ? () : @cfg_base)));
     }
 
-    @dirs = grep { -d $_ && -r $_ } uniq(@dirs);
+    @dirs = grep { -d $_ && -r $_ } distinct(@dirs);
 
     @dirs;
 }
@@ -584,7 +601,7 @@ and remind about C</usr/local/etc>.
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2010-2017 Jens Rehsack.
+Copyright 2010-2018 Jens Rehsack.
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of either: the GNU General Public License as published
